"""
Constants used in ABED

"""

#: Default filename for the abed config file.
CONFIG_FILENAME = 'abed_conf.py'

#: Default dataset directory name
DATASET_DIRNAME = 'datasets'

#: Default executables directory name
EXECS_DIRNAME = 'execs'

#: Default tasksfile filename
TASKS_FILENAME = 'abed_tasks.txt'

#: Default auto filename
AUTO_FILENAME = 'abed_auto.txt'
